@@ -8,21 +8,25 @@ test_xapo_api
 Tests for `xapo_api` module.
 """
 
-import unittest
+import unittest2
 
 import uuid
 from xapo_sdk import xapo_api
 
+TEST = False
 
-class TestXapo_tools(unittest.TestCase):
 
+# TODO set your credentials ans TEST to True
+@unittest2.skipIf(not TEST, "Set your credentials and TEST to True")
+class TestXapo_tools(unittest2.TestCase):
     def setUp(self):
-        self.api = xapo_api.API('http://dev.xapo.com/api/v1',
-                                'b91014cc28c94841',
-                                'c533a6e606fb62ccb13e8baf8a95cbdc')
+        self.api = xapo_api.API('https://api.xapo.com/v1',
+                                'your app id',
+                                'your app secret')
 
     def test_credit(self):
-        res = self.api.credit(to='sample@xapo.com', amount=0.5,
+        res = self.api.credit(to='sample@xapo.com', amount=1,
+                              currency=xapo_api.Currency.SAT,
                               comments='Sample deposit',
                               request_id=uuid.uuid1().hex)
 
